# Eelbrain

[![DOI](https://zenodo.org/badge/3651023.svg)](https://zenodo.org/badge/latestdoi/3651023)
[![Anaconda-Server Badge](https://anaconda.org/christianbrodbeck/eelbrain/badges/installer/conda.svg)](https://github.com/christianbrodbeck/Eelbrain/wiki/Installing)


| Stable | Pre-release |
| ------ | ----------- |
| [![Conda Version](https://img.shields.io/conda/vn/conda-forge/eelbrain)](https://anaconda.org/conda-forge/eelbrain) | [![Anaconda-Server Badge](https://anaconda.org/conda-forge/eelbrain/badges/version.svg)](https://anaconda.org/conda-forge/eelbrain/labels) |

Main documentation at: http://eelbrain.readthedocs.io

## Build status

[![Build Status](https://travis-ci.org/christianbrodbeck/Eelbrain.svg?branch=master)](https://travis-ci.org/christianbrodbeck/Eelbrain) 
[![Appveyor Status](https://ci.appveyor.com/api/projects/status/5rwhgtsfku953f12/branch/master?svg=true)](https://ci.appveyor.com/project/christianbrodbeck/eelbrain/branch/master)
[![Documentation Status](https://readthedocs.org/projects/eelbrain/badge/?version=latest)](http://eelbrain.readthedocs.io/en/latest/) 


## Conda-forge

[![Conda Recipe](https://img.shields.io/badge/recipe-eelbrain-green.svg)](https://github.com/conda-forge/eelbrain-feedstock)
[![Linux](https://img.shields.io/circleci/project/github/conda-forge/eelbrain-feedstock/master.svg?label=Linux)](https://circleci.com/gh/conda-forge/eelbrain-feedstock)
[![OSX](https://img.shields.io/travis/conda-forge/eelbrain-feedstock/master.svg?label=macOS)](https://travis-ci.org/conda-forge/eelbrain-feedstock)
[![Windows](https://img.shields.io/appveyor/ci/conda-forge/eelbrain-feedstock/master.svg?label=Windows)](https://ci.appveyor.com/project/conda-forge/eelbrain-feedstock/branch/master)
